Description Usage Arguments Details Value Author(s) References See Also Examples
SXTerrorbar is used to add error bar.
1 | SXTerrorbar(x, y, upper, lower=upper, length=0.1,...)
|
| data1: | The MS data1, first column is mz and second column is RT. |
| data2: | The MS data2, first column is mz and second column is RT. |
| mz.tolerance: | The tolerance of m/z. |
| rt.tolerance: | The tolerance of retention time. |
| Package: | SXTerrorbar |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2016-08-16 |
| License: | Nothing |
| Depends: | R (> = 3.1.1) |
| result: | The matching result of index, mz error and rt error. |
Jasper Shen
Maintainer: Jasper Shen <shenxt1990@163.com>
No
1 | sorry, no example
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.